@@ -31,6 +31,7 @@ class RBackend : public Cantor::Backend
     ~RBackend();
 
     QString id() const;
+    QString version() const override;
     Cantor::Session *createSession();
     Cantor::Backend::Capabilities capabilities() const;
     bool requirementsFullfilled() const;
@@ -38,7 +39,7 @@ class RBackend : public Cantor::Backend
     virtual QWidget* settingsWidget(QWidget* parent) const;
     virtual KConfigSkeleton* config() const;
 
-    KUrl helpUrl() const;
+    QUrl helpUrl() const;
     QString description() const;
 };
 
