@@ -25,7 +25,7 @@
 #include <analitza/analyzer.h>
 #include <QTextEdit>
 
-#include <kdebug.h>
+#include <QDebug>
 #include "kalgebrasyntaxhelpobject.h"
 #include <analitzagui/operatorsmodel.h>
 #include <analitzagui/variablesmodel.h>
@@ -46,14 +46,15 @@ KAlgebraSession::~KAlgebraSession()
 
 void KAlgebraSession::login()
 {
+    emit loginStarted();
     if(!KAlgebraSettings::autorunScripts().isEmpty()){
-        QString autorunScripts = KAlgebraSettings::self()->autorunScripts().join("\n");
+        QString autorunScripts = KAlgebraSettings::self()->autorunScripts().join(QLatin1String("\n"));
 
         evaluateExpression(autorunScripts, KAlgebraExpression::DeleteOnFinish);
     }
 
     changeStatus(Cantor::Session::Done);
-    emit ready();
+    emit loginDone();
 }
 
 void KAlgebraSession::logout()
