@@ -22,7 +22,7 @@
 #define _LUASESSION_H
 
 #include "session.h"
-#include <luajit-2.0/lua.hpp> // need the luajit-2.0 prefix to avoid conflicts with Lua 5.2
+#include <lua.hpp>
 
 class LuaExpression;
 
