@@ -34,9 +34,9 @@ class MaximaSyntaxHelpObject : public Cantor::SyntaxHelpObject
     MaximaSyntaxHelpObject( const QString& command, MaximaSession* session );
     ~MaximaSyntaxHelpObject();
 
-  protected slots:
-    void fetchInformation();
-  private slots:
+  protected Q_SLOTS:
+    void fetchInformation() Q_DECL_OVERRIDE;
+  private Q_SLOTS:
     void expressionChangedStatus(Cantor::Expression::Status status);
 
   private:
