@@ -31,7 +31,6 @@
 #include "pythonsession.h"
 #include "settings.h"
 
-#include "imageresult.h"
 #include <QDir>
 typedef Cantor::ImageResult PythonPlotResult;
 
@@ -96,7 +95,7 @@ void PythonExpression::parsePlotFile(const QString& filename)
 
     qDebug() << "PythonExpression::parsePlotFile: " << filename;
 
-    setResult(new PythonPlotResult(filename));
+    setResult(new PythonPlotResult(QUrl::fromLocalFile(filename)));
 
     setPlotPending(false);
 
