@@ -82,27 +82,27 @@ class WorksheetAccessInterfaceImpl : public Cantor::WorksheetAccessInterface
 
     }
 
-    virtual QByteArray saveWorksheetToByteArray()
+    QByteArray saveWorksheetToByteArray() Q_DECL_OVERRIDE
     {
         return m_worksheet->saveToByteArray();
     }
 
-    virtual void loadWorksheetFromByteArray(QByteArray* data)
+    void loadWorksheetFromByteArray(QByteArray* data) Q_DECL_OVERRIDE
     {
         m_worksheet->load(data);
     }
 
-    virtual Cantor::Session* session()
+    Cantor::Session* session() Q_DECL_OVERRIDE
     {
         return m_worksheet->session();
     }
 //  public Q_SLOTS:
-  void evaluate()
+  void evaluate() Q_DECL_OVERRIDE
     {
         m_worksheet->evaluate();
     }
 
-    void interrupt()
+    void interrupt() Q_DECL_OVERRIDE
     {
         m_worksheet->interrupt();
     }
@@ -272,22 +272,20 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     connect(restart, SIGNAL(triggered()), this, SLOT(restartBackend()));
 
     QAction * evaluateCurrent=new QAction(i18n("Evaluate Entry"), actionCollection());
-    evaluateCurrent->setShortcut(Qt::SHIFT + Qt::Key_Return);
     actionCollection()->addAction(QLatin1String("evaluate_current"),  evaluateCurrent);
+    actionCollection()->setDefaultShortcut(evaluateCurrent, Qt::SHIFT + Qt::Key_Return);
     connect(evaluateCurrent, SIGNAL(triggered()), m_worksheet, SLOT(evaluateCurrentEntry()));
 
     QAction * insertCommandEntry=new QAction(i18n("Insert Command Entry"), actionCollection());
-    insertCommandEntry->setShortcut(Qt::CTRL + Qt::Key_Return);
     actionCollection()->addAction(QLatin1String("insert_command_entry"),  insertCommandEntry);
+    actionCollection()->setDefaultShortcut(insertCommandEntry, Qt::CTRL + Qt::Key_Return);
     connect(insertCommandEntry, SIGNAL(triggered()), m_worksheet, SLOT(insertCommandEntry()));
 
     QAction * insertTextEntry=new QAction(i18n("Insert Text Entry"), actionCollection());
-    //insertEntry->setShortcut(Qt::CTRL + Qt::Key_Return);
     actionCollection()->addAction(QLatin1String("insert_text_entry"),  insertTextEntry);
     connect(insertTextEntry, SIGNAL(triggered()), m_worksheet, SLOT(insertTextEntry()));
 
     QAction * insertLatexEntry=new QAction(i18n("Insert Latex Entry"), actionCollection());
-    //insertEntry->setShortcut(Qt::CTRL + Qt::Key_Return);
     actionCollection()->addAction(QLatin1String("insert_latex_entry"),  insertLatexEntry);
     connect(insertLatexEntry, SIGNAL(triggered()), m_worksheet, SLOT(insertLatexEntry()));
 
@@ -322,8 +320,8 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     */
 
     QAction * removeCurrent=new QAction(i18n("Remove current Entry"), actionCollection());
-    removeCurrent->setShortcut(Qt::ShiftModifier + Qt::Key_Delete);
     actionCollection()->addAction(QLatin1String("remove_current"), removeCurrent);
+    actionCollection()->setDefaultShortcut(removeCurrent, Qt::ShiftModifier + Qt::Key_Delete);
     connect(removeCurrent, SIGNAL(triggered()), m_worksheet, SLOT(removeCurrentEntry()));
 
     m_showBackendHelp=new QAction(i18n("Show %1 Help", b->name()) , actionCollection());
@@ -346,7 +344,7 @@ CantorPart::CantorPart( QWidget *parentWidget, QObject *parent, const QVariantLi
     actionCollection()->addAction(QLatin1String("show_completion"), showCompletion);
     QList<QKeySequence> showCompletionShortcuts;
     showCompletionShortcuts << Qt::Key_Tab << Qt::CTRL + Qt::Key_Space;
-    showCompletion->setShortcuts(showCompletionShortcuts);
+    actionCollection()->setDefaultShortcuts(showCompletion, showCompletionShortcuts);
     connect(showCompletion, SIGNAL(triggered()), m_worksheet, SLOT(showCompletion()));
 
     // set our XML-UI resource file
@@ -553,40 +551,36 @@ void CantorPart::showSessionError(const QString& message)
 void CantorPart::worksheetSessionChanged()
 {
     connect(m_worksheet->session(), SIGNAL(statusChanged(Cantor::Session::Status)), this, SLOT(worksheetStatusChanged(Cantor::Session::Status)));
-    connect(m_worksheet->session(), SIGNAL(ready()),this, SLOT(initialized()));
+    connect(m_worksheet->session(), SIGNAL(loginStarted()),this, SLOT(worksheetSessionLoginStarted()));
+    connect(m_worksheet->session(), SIGNAL(loginDone()),this, SLOT(worksheetSessionLoginDone()));
     connect(m_worksheet->session(), SIGNAL(error(const QString&)), this, SLOT(showSessionError(const QString&)));
 
     loadAssistants();
     m_panelHandler->setSession(m_worksheet->session());
     adjustGuiToSession();
-
-    if(m_showProgressDlg && !m_initProgressDlg)
-    {
-        m_initProgressDlg = new QProgressDialog(widget());
-        m_initProgressDlg->setWindowTitle(i18n("Cantor"));
-        m_initProgressDlg->setLabelText(i18n("Initializing Session"));
-        m_initProgressDlg->setMinimumDuration(500);
-        m_initProgressDlg->setRange(0, 0);
-        m_initProgressDlg->exec();
-    }
+    initialized();
 }
 
 void CantorPart::initialized()
 {
     if (m_worksheet->isEmpty())
         m_worksheet->appendCommandEntry();
+
     m_worksheetview->setEnabled(true);
     m_worksheetview->setFocus();
     setStatusMessage(i18n("Initialization complete"));
-
-    if(m_initProgressDlg)
-    {
-        m_initProgressDlg->deleteLater();
-        m_initProgressDlg=0;
-    }
     updateCaption();
 }
 
+void CantorPart::worksheetSessionLoginStarted() {
+    setStatusMessage(i18n("Initializing..."));
+    QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+}
+
+void CantorPart::worksheetSessionLoginDone() {
+    QApplication::restoreOverrideCursor();
+}
+
 void CantorPart::enableTypesetting(bool enable)
 {
     m_worksheet->session()->setTypesettingEnabled(enable);
