@@ -31,20 +31,20 @@ class CANTOR_EXPORT AnimationResult : public Result
 {
   public:
     enum{Type=6};
-    explicit AnimationResult( const KUrl& url, const QString& alt=QString() );
+    explicit AnimationResult( const QUrl& url, const QString& alt=QString() );
     ~AnimationResult();
 
-    QString toHtml();
-    QVariant data();
-    KUrl url();
+    QString toHtml() Q_DECL_OVERRIDE;
+    QVariant data() Q_DECL_OVERRIDE;
+    QUrl url() Q_DECL_OVERRIDE;
 
-    int type();
-    QString mimeType();
+    int type() Q_DECL_OVERRIDE;
+    QString mimeType() Q_DECL_OVERRIDE;
 
-    QDomElement toXml(QDomDocument& doc);
-    void saveAdditionalData(KZip* archive);
+    QDomElement toXml(QDomDocument& doc) Q_DECL_OVERRIDE;
+    void saveAdditionalData(KZip* archive) Q_DECL_OVERRIDE;
 
-    void save(const QString& filename);
+    void save(const QString& filename) Q_DECL_OVERRIDE;
   private:
     AnimationResultPrivate* d;
 
