@@ -28,7 +28,6 @@ class Session;
 }
 
 class QTreeView;
-class QToolButton;
 class QAbstractItemModel;
 
 class VariableManagerWidget : public QWidget
@@ -40,24 +39,20 @@ class VariableManagerWidget : public QWidget
 
     void setSession(Cantor::Session* session);
 
-  public slots:
+  public Q_SLOTS:
     void clearVariables();
 
     void save();
     void load();
     void newVariable();
 
-  signals:
+  Q_SIGNALS:
     void runCommand(const QString& cmd);
 
   private:
     Cantor::Session* m_session;
     QAbstractItemModel* m_model;
     QTreeView* m_table;
-    QToolButton* m_newBtn;
-    QToolButton* m_loadBtn;
-    QToolButton* m_saveBtn;
-    QToolButton* m_clearBtn;
 };
 
 #endif /* _VARIABLEMANAGERWIDGET_H */
