@@ -42,42 +42,42 @@ class TextEntry : public WorksheetEntry
     ~TextEntry();
 
     enum {Type = UserType + 1};
-    int type() const;
+    int type() const Q_DECL_OVERRIDE;
 
-    bool isEmpty();
+    bool isEmpty() Q_DECL_OVERRIDE;
 
-    bool acceptRichText();
+    bool acceptRichText() Q_DECL_OVERRIDE;
 
-    bool focusEntry(int pos = WorksheetTextItem::TopLeft, qreal xCoord=0);
+    bool focusEntry(int pos = WorksheetTextItem::TopLeft, qreal xCoord=0) Q_DECL_OVERRIDE;
 
     // do we need/get this?
     //bool worksheetContextMenuEvent(...);
     //void mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event);
 
-    void setContent(const QString& content);
-    void setContent(const QDomElement& content, const KZip& file);
+    void setContent(const QString& content) Q_DECL_OVERRIDE;
+    void setContent(const QDomElement& content, const KZip& file) Q_DECL_OVERRIDE;
 
-    QDomElement toXml(QDomDocument& doc, KZip* archive);
-    QString toPlain(const QString& commandSep, const QString& commentStartingSeq, const QString& commentEndingSeq);
+    QDomElement toXml(QDomDocument& doc, KZip* archive) Q_DECL_OVERRIDE;
+    QString toPlain(const QString& commandSep, const QString& commentStartingSeq, const QString& commentEndingSeq) Q_DECL_OVERRIDE;
 
-    void interruptEvaluation();
+    void interruptEvaluation() Q_DECL_OVERRIDE;
 
-    void layOutForWidth(qreal w, bool force = false);
+    void layOutForWidth(qreal w, bool force = false) Q_DECL_OVERRIDE;
 
     int searchText(QString text, QString pattern,
                    QTextDocument::FindFlags qt_flags);
     WorksheetCursor search(QString pattern, unsigned flags,
                            QTextDocument::FindFlags qt_flags,
-                           const WorksheetCursor& pos = WorksheetCursor());
+                           const WorksheetCursor& pos = WorksheetCursor()) Q_DECL_OVERRIDE;
 
   public Q_SLOTS:
-    bool evaluate(EvaluationOption evalOp = FocusNext);
+    bool evaluate(EvaluationOption evalOp = FocusNext) Q_DECL_OVERRIDE;
     void resolveImagesAtCursor();
-    void updateEntry();
-    void populateMenu(QMenu *menu, const QPointF& pos);
+    void updateEntry() Q_DECL_OVERRIDE;
+    void populateMenu(QMenu *menu, const QPointF& pos) Q_DECL_OVERRIDE;
 
   protected:
-    bool wantToEvaluate();
+    bool wantToEvaluate() Q_DECL_OVERRIDE;
 
   private:
     QTextCursor findLatexCode(QTextCursor cursor = QTextCursor()) const;
