@@ -66,8 +66,17 @@ Worksheet::Worksheet(Cantor::Backend* backend, QWidget* parent)
     m_dragScrollTimer = 0;
 
     m_isPrinting = false;
-    m_loginFlag = true;
-    QTimer::singleShot(0, this, SLOT(loginToSession()));
+    m_loginDone = false;
+
+    enableHighlighting(Settings::self()->highlightDefault());
+    enableCompletion(Settings::self()->completionDefault());
+    enableExpressionNumbering(Settings::self()->expressionNumberingDefault());
+    enableAnimations(Settings::self()->animationDefault());
+#ifdef WITH_EPS
+    session()->setTypesettingEnabled(Settings::self()->typesetDefault());
+#else
+    session()->setTypesettingEnabled(false);
+#endif
 }
 
 Worksheet::~Worksheet()
@@ -76,27 +85,14 @@ Worksheet::~Worksheet()
     // while the scene is deleted. Maybe there is a better solution to
     // this problem, but I can't seem to find it.
     m_firstEntry = 0;
-    m_session->logout();
+    if (m_loginDone)
+        m_session->logout();
 }
 
 void Worksheet::loginToSession()
 {
-    if(m_loginFlag==true)
-    {
-        m_session->login();
-
-        enableHighlighting(Settings::self()->highlightDefault());
-        enableCompletion(Settings::self()->completionDefault());
-        enableExpressionNumbering(Settings::self()->expressionNumberingDefault());
-        enableAnimations(Settings::self()->animationDefault());
-#ifdef WITH_EPS
-        session()->setTypesettingEnabled(Settings::self()->typesetDefault());
-#else
-        session()->setTypesettingEnabled(false);
-#endif
-
-        m_loginFlag=false;
-    }
+    m_session->login();
+    m_loginDone = true;
 }
 
 void Worksheet::print(QPrinter* printer)
@@ -448,6 +444,9 @@ void Worksheet::startDrag(WorksheetEntry* entry, QDrag* drag)
 void Worksheet::evaluate()
 {
     qDebug()<<"evaluate worksheet";
+    if (!m_loginDone)
+        loginToSession();
+
     firstEntry()->evaluate(WorksheetEntry::EvaluateNext);
 
     emit modified();
@@ -455,7 +454,9 @@ void Worksheet::evaluate()
 
 void Worksheet::evaluateCurrentEntry()
 {
-    qDebug() << "evaluation requested...";
+    if (!m_loginDone)
+        loginToSession();
+
     WorksheetEntry* entry = currentEntry();
     if(!entry)
         return;
@@ -601,7 +602,6 @@ void Worksheet::insertCommandEntry(const QString& text)
     }
 }
 
-
 WorksheetEntry* Worksheet::insertEntryBefore(int type, WorksheetEntry* current)
 {
     if (!current)
@@ -992,7 +992,6 @@ void Worksheet::load(QIODevice* device)
     clear();
 
     m_session=b->createSession();
-    m_loginFlag=true;
 
     qDebug()<<"loading entries";
     QDomElement expressionChild = root.firstChildElement();
@@ -1031,7 +1030,7 @@ void Worksheet::load(QIODevice* device)
 
     //Set the Highlighting, depending on the current state
     //If the session isn't logged in, use the default
-    enableHighlighting( m_highlighter!=0 || (m_loginFlag && Settings::highlightDefault()) );
+    enableHighlighting( m_highlighter!=0 || Settings::highlightDefault() );
 
     emit sessionChanged();
 }
@@ -1199,9 +1198,8 @@ void Worksheet::createActions(KActionCollection* collection)
     m_boldAction->setFont(bold);
     m_richTextActionList.append(m_boldAction);
     collection->addAction(QLatin1String("format_text_bold"), m_boldAction);
-    m_boldAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_B));
-    connect(m_boldAction, SIGNAL(triggered(bool)), this,
-            SLOT(setTextBold(bool)));
+    collection->setDefaultShortcut(m_boldAction, Qt::CTRL + Qt::Key_B);
+    connect(m_boldAction, SIGNAL(triggered(bool)), this, SLOT(setTextBold(bool)));
 
     // Italic
     m_italicAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-text-italic")),
@@ -1214,9 +1212,8 @@ void Worksheet::createActions(KActionCollection* collection)
     m_italicAction->setFont(italic);
     m_richTextActionList.append(m_italicAction);
     collection->addAction(QLatin1String("format_text_italic"), m_italicAction);
-    m_italicAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_I));
-    connect(m_italicAction, SIGNAL(triggered(bool)), this,
-            SLOT(setTextItalic(bool)));
+    collection->setDefaultShortcut(m_italicAction, Qt::CTRL + Qt::Key_I);
+    connect(m_italicAction, SIGNAL(triggered(bool)), this, SLOT(setTextItalic(bool)));
 
     // Underline
     m_underlineAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-text-underline")),
@@ -1229,9 +1226,8 @@ void Worksheet::createActions(KActionCollection* collection)
     m_underlineAction->setFont(underline);
     m_richTextActionList.append(m_underlineAction);
     collection->addAction(QLatin1String("format_text_underline"), m_underlineAction);
-    m_underlineAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_U));
-    connect(m_underlineAction, SIGNAL(triggered(bool)), this,
-            SLOT(setTextUnderline(bool)));
+    collection->setDefaultShortcut(m_underlineAction, Qt::CTRL + Qt::Key_U);
+    connect(m_underlineAction, SIGNAL(triggered(bool)), this, SLOT(setTextUnderline(bool)));
 
     // Strike
     m_strikeOutAction = new KToggleAction(QIcon::fromTheme(QLatin1String("format-text-strikethrough")),
@@ -1240,9 +1236,8 @@ void Worksheet::createActions(KActionCollection* collection)
     m_strikeOutAction->setPriority(QAction::LowPriority);
     m_richTextActionList.append(m_strikeOutAction);
     collection->addAction(QLatin1String("format_text_strikeout"), m_strikeOutAction);
-    m_strikeOutAction->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_L));
-    connect(m_strikeOutAction, SIGNAL(triggered(bool)), this,
-            SLOT(setTextStrikeOut(bool)));
+    collection->setDefaultShortcut(m_strikeOutAction, Qt::CTRL + Qt::Key_L);
+    connect(m_strikeOutAction, SIGNAL(triggered(bool)), this, SLOT(setTextStrikeOut(bool)));
 
     // Alignment
     QActionGroup *alignmentGroup = new QActionGroup(this);
@@ -1539,7 +1534,6 @@ bool Worksheet::isShortcut(QKeySequence sequence)
 
 void Worksheet::registerShortcut(QAction* action)
 {
-    qDebug() << action->shortcuts();
     foreach(QKeySequence shortcut, action->shortcuts()) {
         m_shortcuts.insert(shortcut, action);
     }
